@@ -121,7 +121,7 @@ QString Freecell::solverFormat() const
     for (int i = 0; i < 4 ; i++) {
         if (target[i]->isEmpty())
             continue;
-        tmp += suitToString(target[i]->topCard()->suit()) + '-' + rankToString(target[i]->topCard()->rank()) + ' ';
+        tmp += suitToString(target[i]->topCard()->suit()) + QLatin1Char('-') + rankToString(target[i]->topCard()->rank()) + QLatin1Char(' ');
     }
     if (!tmp.isEmpty())
         output += QStringLiteral("Foundations: %1\n").arg(tmp);
@@ -129,7 +129,7 @@ QString Freecell::solverFormat() const
     tmp.truncate(0);
     for (int i = 0; i < 4 ; i++) {
         const auto fc = freecell[i];
-        tmp += (fc->isEmpty() ? QStringLiteral("-") : cardToRankSuitString(fc->topCard())) + ' ';
+        tmp += (fc->isEmpty() ? QStringLiteral("-") : cardToRankSuitString(fc->topCard())) + QLatin1Char(' ');
     }
     if (!tmp.isEmpty())
     {
@@ -243,8 +243,8 @@ QList<MoveHint> Freecell::getHints()
     if ( isDemoActive() )
         return hintList;
 
-    foreach (PatPile * store, patPiles())
-    {
+    const auto patPiles = this->patPiles();
+    for (PatPile * store : patPiles) {
         if (store->isEmpty())
             continue;
 
@@ -257,8 +257,8 @@ QList<MoveHint> Freecell::getHints()
         {
             if (allowedToRemove(store, (*iti)))
             {
-                foreach (PatPile * dest, patPiles())
-                {
+                const auto patPiles = this->patPiles();
+                for (PatPile * dest : patPiles) {
                     int cardIndex = store->indexOf(*iti);
                     if (cardIndex == 0 && dest->isEmpty() && !dest->isFoundation())
                         continue;
