@@ -132,7 +132,7 @@ void Golf::restart( const QList<KCard*> & cards )
 
     flipCardToPile(talon->topCard(), waste, DURATION_MOVE);
 
-    emit newCardsPossible( true );
+    Q_EMIT newCardsPossible( true );
 }
 
 
@@ -144,7 +144,7 @@ bool Golf::newCards()
     flipCardToPile(talon->topCard(), waste, DURATION_MOVE);
 
     if ( talon->isEmpty() )
-        emit newCardsPossible( false );
+        Q_EMIT newCardsPossible( false );
 
     return true;
 }
@@ -170,13 +170,13 @@ bool Golf::drop()
 void Golf::setGameState( const QString & state )
 {
     Q_UNUSED( state );
-    emit newCardsPossible( !talon->isEmpty() );
+    Q_EMIT newCardsPossible( !talon->isEmpty() );
 }
 
 QString Golf::solverFormat() const
 {
     QString output;
-    output += QLatin1String("Foundations: ") + (waste->isEmpty() ? QLatin1String("-") : cardToRankSuitString(waste->topCard())) + '\n';
+    output += QLatin1String("Foundations: ") + (waste->isEmpty() ? QLatin1String("-") : cardToRankSuitString(waste->topCard())) + QLatin1Char('\n');
     output += QLatin1String("Talon:");
     for ( int i = talon->count()-1; i >= 0; --i )
     {
